//
// Cursors.cs
//
// Contact:
//   Moonlight List (moonlight-list@lists.ximian.com)
//
// Copyright 2007 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;

namespace System.Windows.Input {

	public static class Cursors {
		public static Cursor None {
			get { return new Cursor (CursorType.None); }
		}
		public static Cursor Arrow {
			get { return new Cursor (CursorType.Arrow); }
		}
		public static Cursor SizeWE {
			get { throw new NotImplementedException(); }
		}
		public static Cursor Eraser {
			get { return new Cursor (CursorType.Eraser); }
		}
		public static Cursor Hand {
			get { return new Cursor (CursorType.Hand); }
		}
		public static Cursor Wait {
			get { return new Cursor (CursorType.Wait); }
		}
		public static Cursor SizeNS {
			get { throw new NotImplementedException(); }
		}
		public static Cursor IBeam {
			get { return new Cursor (CursorType.IBeam); }
		}
		public static Cursor Stylus {
			get { return new Cursor (CursorType.Stylus); }
		}
	}
}
